@@ -315,7 +315,7 @@ static QStringList parseEnvCommandLine(const QString &cmdLine)
 
 scoped_refptr<QtWebEngineCore::WebEngineContext> WebEngineContext::m_handle;
 bool WebEngineContext::m_destroyed = false;
-
+bool WebEngineContext::m_closingDown = false;
 void WebEngineContext::destroyProfileAdapter()
 {
     if (content::RenderProcessHost::run_renderer_in_process()) {
@@ -484,6 +484,7 @@ void WebEngineContext::destroyContextPostRoutine()
     // Destroy WebEngineContext before its static pointer is zeroed and destructor called.
     // Before destroying MessageLoop via destroying BrowserMainRunner destructor
     // WebEngineContext's pointer is used.
+    m_closingDown = true;
     m_handle->destroy();
 #if !defined(NDEBUG)
     if (!m_handle->HasOneRef())
@@ -636,6 +637,7 @@ WebEngineContext::WebEngineContext()
 
     parsedCommandLine->AppendSwitch(switches::kEnableThreadedCompositing);
 
+#if QT_CONFIG(opengl)
 #if defined(Q_OS_WIN)
     // This switch is used in Chromium's gl_context_wgl.cc file to determine whether to create
     // an OpenGL Core Profile context. If the switch is not set, it would always try to create a
@@ -658,7 +660,8 @@ WebEngineContext::WebEngineContext()
 
     if (isDesktopGLOrSoftware || isGLES2Context)
         parsedCommandLine->AppendSwitch(switches::kDisableES3GLContext);
-#endif
+#endif // defined(Q_OS_WIN)
+#endif // QT_CONFIG(opengl)
 
     // Do not advertise a feature we have removed at compile time
     parsedCommandLine->AppendSwitch(switches::kDisableSpeechAPI);
@@ -671,6 +674,7 @@ WebEngineContext::WebEngineContext()
     // upstream Chromium commit ba52f56207a4b9d70b34880fbff2352e71a06422.
     enableFeatures.push_back(features::kAllowContentInitiatedDataUrlNavigations.name);
 
+    enableFeatures.push_back(features::kNetworkServiceInProcess.name);
     enableFeatures.push_back(features::kTracingServiceInProcess.name);
 
     // The video-capture service is not functioning at this moment (since 69)
@@ -794,6 +798,7 @@ WebEngineContext::WebEngineContext()
     registerMainThreadFactories();
 
     content::ContentMainParams contentMainParams(m_mainDelegate.get());
+    contentMainParams.setup_signal_handlers = false;
 #if defined(OS_WIN)
     contentMainParams.sandbox_info = staticSandboxInterfaceInfo();
     sandbox::SandboxInterfaceInfo sandbox_info = {0};
@@ -931,4 +936,9 @@ base::CommandLine* WebEngineContext::commandLine() {
     }
 }
 
+bool WebEngineContext::closingDown()
+{
+    return m_closingDown;
+}
+
 } // namespace
